Ignite supports integration with databases 'out-of-the-box' by `org.apache.ignite.cache.store.jdbc.CacheJdbcPojoStore` class that implements `org.apache.ignite.cache.store.CacheStore` interface.

Ignite provides utility that will read database metadata and generate POJO classes and XML configuration.

Utility can be started by script:
[block:code]
{
  "codes": [
    {
      "code": "$ bin/ignite-schema-load.sh",
      "language": "shell"
    }
  ]
}
[/block]

[block:api-header]
{
  "type": "basic",
  "title": "Connect to database"
}
[/block]
JDBC drivers **are not supplied** with utility. You should download (and install if needed) appropriate JDBC driver for your database.
[block:image]
{
  "images": [
    {
      "image": [
        "https://www.filepicker.io/api/file/jKCMIgmTi2uqSqgkgiTQ",
        "ignite-schema-load-01.png",
        "650",
        "650",
        "#d6363a",
        ""
      ]
    }
  ]
}
[/block]

[block:api-header]
{
  "type": "basic",
  "title": "Generate XML configuration and POJO classes"
}
[/block]
Select tables you want to map to POJO classes and click 'Generate' button.
[block:image]
{
  "images": [
    {
      "image": [
        "https://www.filepicker.io/api/file/13YM8mBRXaTB8yXWJkWI",
        "ignite-schema-load-02.png",
        "650",
        "650",
        "",
        ""
      ]
    }
  ]
}
[/block]

[block:api-header]
{
  "type": "basic",
  "title": "Produced output"
}
[/block]
Utility will generate POJO classes,  XML configuration, and java code snippet of cache configuration by code.
[block:code]
{
  "codes": [
    {
      "code": "/**\n * PersonKey definition.\n *\n * Code generated by Apache Ignite Schema Load utility: 03/03/2015.\n */\npublic class PersonKey implements Serializable {\n    /** */\n    private static final long serialVersionUID = 0L;\n\n    /** Value for id. */\n    private int id;\n\n    /**\n     * Gets id.\n     *\n     * @return Value for id.\n     */\n    public int getId() {\n        return id;\n    }\n\n    /**\n     * Sets id.\n     *\n     * @param id New value for id.\n     */\n    public void setId(int id) {\n        this.id = id;\n    }\n\n    /** {@inheritDoc} */\n    @Override public boolean equals(Object o) {\n        if (this == o)\n            return true;\n\n        if (!(o instanceof PersonKey))\n            return false;\n\n        PersonKey that = (PersonKey)o;\n\n        if (id != that.id)\n            return false;\n\n        return true;\n    }\n\n    /** {@inheritDoc} */\n    @Override public int hashCode() {\n        int res = id;\n\n        return res;\n    }\n\n    /** {@inheritDoc} */\n    @Override public String toString() {\n        return \"PersonKey [id=\" + id +\n            \"]\";\n    }\n}",
      "language": "java",
      "name": "POJO Key class"
    },
    {
      "code": "/**\n * Person definition.\n *\n * Code generated by Apache Ignite Schema Load utility: 03/03/2015.\n */\npublic class Person implements Serializable {\n    /** */\n    private static final long serialVersionUID = 0L;\n\n    /** Value for id. */\n    private int id;\n\n    /** Value for orgId. */\n    private Integer orgId;\n\n    /** Value for name. */\n    private String name;\n\n    /**\n     * Gets id.\n     *\n     * @return Value for id.\n     */\n    public int getId() {\n        return id;\n    }\n\n    /**\n     * Sets id.\n     *\n     * @param id New value for id.\n     */\n    public void setId(int id) {\n        this.id = id;\n    }\n\n    /**\n     * Gets orgId.\n     *\n     * @return Value for orgId.\n     */\n    public Integer getOrgId() {\n        return orgId;\n    }\n\n    /**\n     * Sets orgId.\n     *\n     * @param orgId New value for orgId.\n     */\n    public void setOrgId(Integer orgId) {\n        this.orgId = orgId;\n    }\n\n    /**\n     * Gets name.\n     *\n     * @return Value for name.\n     */\n    public String getName() {\n        return name;\n    }\n\n    /**\n     * Sets name.\n     *\n     * @param name New value for name.\n     */\n    public void setName(String name) {\n        this.name = name;\n    }\n\n    /** {@inheritDoc} */\n    @Override public boolean equals(Object o) {\n        if (this == o)\n            return true;\n\n        if (!(o instanceof Person))\n            return false;\n\n        Person that = (Person)o;\n\n        if (id != that.id)\n            return false;\n\n        if (orgId != null ? !orgId.equals(that.orgId) : that.orgId != null)\n            return false;\n\n        if (name != null ? !name.equals(that.name) : that.name != null)\n            return false;\n\n        return true;\n    }\n\n    /** {@inheritDoc} */\n    @Override public int hashCode() {\n        int res = id;\n\n        res = 31 * res + (orgId != null ? orgId.hashCode() : 0);\n\n        res = 31 * res + (name != null ? name.hashCode() : 0);\n\n        return res;\n    }\n\n    /** {@inheritDoc} */\n    @Override public String toString() {\n        return \"Person [id=\" + id +\n            \", orgId=\" + orgId +\n            \", name=\" + name +\n            \"]\";\n    }\n}",
      "language": "java",
      "name": "POJO Value class"
    },
    {
      "code": "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<beans xmlns=\"http://www.springframework.org/schema/beans\"\n       xmlns:util=\"http://www.springframework.org/schema/util\"\n       xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n       xsi:schemaLocation=\"http://www.springframework.org/schema/beans\n                           http://www.springframework.org/schema/beans/spring-beans.xsd\n                           http://www.springframework.org/schema/util\n                           http://www.springframework.org/schema/util/spring-util.xsd\">\n    <bean class=\"org.apache.ignite.cache.CacheTypeMetadata\">\n        <property name=\"databaseSchema\" value=\"PUBLIC\"/>\n        <property name=\"databaseTable\" value=\"PERSON\"/>\n        <property name=\"keyType\" value=\"org.apache.ignite.examples.datagrid.store.model.PersonKey\"/>\n        <property name=\"valueType\" value=\"org.apache.ignite.examples.datagrid.store.model.Person\"/>\n        <property name=\"keyFields\">\n            <list>\n                <bean class=\"org.apache.ignite.cache.CacheTypeFieldMetadata\">\n                    <property name=\"databaseName\" value=\"ID\"/>\n                    <property name=\"databaseType\">\n                        <util:constant static-field=\"java.sql.Types.INTEGER\"/>\n                    </property>\n                    <property name=\"javaName\" value=\"id\"/>\n                    <property name=\"javaType\" value=\"int\"/>\n                </bean>\n            </list>\n        </property>\n        <property name=\"valueFields\">\n            <list>\n                <bean class=\"org.apache.ignite.cache.CacheTypeFieldMetadata\">\n                    <property name=\"databaseName\" value=\"ID\"/>\n                    <property name=\"databaseType\">\n                        <util:constant static-field=\"java.sql.Types.INTEGER\"/>\n                    </property>\n                    <property name=\"javaName\" value=\"id\"/>\n                    <property name=\"javaType\" value=\"int\"/>\n                </bean>\n                <bean class=\"org.apache.ignite.cache.CacheTypeFieldMetadata\">\n                    <property name=\"databaseName\" value=\"ORG_ID\"/>\n                    <property name=\"databaseType\">\n                        <util:constant static-field=\"java.sql.Types.INTEGER\"/>\n                    </property>\n                    <property name=\"javaName\" value=\"orgId\"/>\n                    <property name=\"javaType\" value=\"java.lang.Integer\"/>\n                </bean>\n                <bean class=\"org.apache.ignite.cache.CacheTypeFieldMetadata\">\n                    <property name=\"databaseName\" value=\"NAME\"/>\n                    <property name=\"databaseType\">\n                        <util:constant static-field=\"java.sql.Types.VARCHAR\"/>\n                    </property>\n                    <property name=\"javaName\" value=\"name\"/>\n                    <property name=\"javaType\" value=\"java.lang.String\"/>\n                </bean>\n            </list>\n        </property>\n    </bean>\n</beans>",
      "language": "xml",
      "name": "XML Configuration"
    },
    {
      "code": "IgniteConfiguration cfg = new IgniteConfiguration();\n...\nCacheConfiguration ccfg = new CacheConfiguration<>();\n\nDataSource dataSource = null; // TODO: Create data source for your database.\n\n// Create store. \nCacheJdbcPojoStore store = new CacheJdbcPojoStore();\nstore.setDataSource(dataSource);\n\n// Create store factory. \nccfg.setCacheStoreFactory(new FactoryBuilder.SingletonFactory<>(store));\n\n// Configure cache to use store. \nccfg.setReadThrough(true);\nccfg.setWriteThrough(true);\n\ncfg.setCacheConfiguration(ccfg);\n\n// Configure cache types. \nCollection<CacheTypeMetadata> meta = new ArrayList<>();\n\n// PERSON.\nCacheTypeMetadata type = new CacheTypeMetadata();\ntype.setDatabaseSchema(\"PUBLIC\");\ntype.setDatabaseTable(\"PERSON\");\ntype.setKeyType(\"org.apache.ignite.examples.datagrid.store.model.PersonKey\");\ntype.setValueType(\"org.apache.ignite.examples.datagrid.store.model.Person\");\n\n// Key fields for PERSON.\nCollection<CacheTypeFieldMetadata> keys = new ArrayList<>();\nkeys.add(new CacheTypeFieldMetadata(\"ID\", java.sql.Types.INTEGER,\"id\", int.class));\ntype.setKeyFields(keys);\n\n// Value fields for PERSON.\nCollection<CacheTypeFieldMetadata> vals = new ArrayList<>();\nvals.add(new CacheTypeFieldMetadata(\"ID\", java.sql.Types.INTEGER,\"id\", int.class));\nvals.add(new CacheTypeFieldMetadata(\"ORG_ID\", java.sql.Types.INTEGER,\"orgId\", Integer.class));\nvals.add(new CacheTypeFieldMetadata(\"NAME\", java.sql.Types.VARCHAR,\"name\", String.class));\ntype.setValueFields(vals);\n...\n// Start Ignite node.\nIgnition.start(cfg);",
      "language": "java",
      "name": "Java snippet"
    }
  ]
}
[/block]
Copy generated POJO java classes to you project source folder.

Copy declaration of CacheTypeMetadata from generated XML file and paste to your project XML configuration file under appropriate CacheConfiguration root.

Or paste snippet with cache configuration into appropriate java class in your project.